@@ -132,9 +132,10 @@ class Endpoint:
         return xml
 
     def get_coordinates(self):
-        return [self.groupId, self.artifactId]
-        +([self.version] if self.version != VERSION_MANAGED else [])
-        +([self.classifier] if self.classifier else [])
+        return ([self.groupId, self.artifactId]
+            + ([self.version] if self.version != Endpoint.VERSION_MANAGED else [])
+            + ([self.classifier] if self.classifier else [])
+            )
 
     def is_endpoint(string):
         endpoint_elements = (
@@ -268,36 +269,9 @@ def launch_java(
 
 
 def run_and_combine_outputs(command, *args):
-    try:
-        command_string = (command,) + args
-        _logger.debug(f"Executing: {command_string}")
-        return subprocess.check_output(command_string, stderr=subprocess.STDOUT)
-    except subprocess.CalledProcessError as e:
-        _logger.error("Error in `%s': %d", " ".join(e.cmd), e.returncode)
-        _logger.debug("Exception: %s", e)
-        _logger.debug("Debug Trace:", exc_info=True)
-        if e.stdout:
-            _logger.debug("\tstd out:")
-            for l in str(e.stdout).split("\\n"):
-                _logger.debug("\t\t%s", l)
-        if e.stderr:
-            _logger.debug("\tstd err:")
-            for l in str(e.stderr).split("\\n"):
-                _logger.debug("\t\t%s", l)
-        sys.exit(e.returncode)
-
-    except NoMainClassInManifest as e:
-        _logger.error(e)
-        _logger.error("No main class given, and none found.")
-        sys.exit(1)
-
-    except HelpRequested:
-        pass
-
-    except Exception as e:
-        _logger.error(e)
-        traceback.print_tb(e.__traceback__)
-        sys.exit(1)
+    command_string = (command,) + args
+    _logger.debug(f"Executing: {command_string}")
+    return subprocess.check_output(command_string, stderr=subprocess.STDOUT)
 
 
 def find_endpoint(argv, shortcuts={}):
@@ -340,8 +314,11 @@ and it will be auto-completed.
 """
 
     parser = argparse.ArgumentParser(
-        description="Run Java main class from maven coordinates.",
-        usage="%(prog)s [-v] [-u] [-U] [-m] [-q] [--log-level] [--ignore-jgorc] [--link-type type] [--additional-jars jar [jar ...]] [--additional-endpoints endpoint [endpoint ...]] [JVM_OPTIONS [JVM_OPTIONS ...]] <endpoint> [main-args]",
+        description="Run Java main class from Maven coordinates.",
+        usage="jgo [-v] [-u] [-U] [-m] [-q] [--log-level] [--ignore-jgorc]\n" +
+              "           [--link-type type] [--additional-jars jar [jar ...]]\n" +
+              "           [--additional-endpoints endpoint [endpoint ...]]\n" +
+              "           [JVM_OPTIONS [JVM_OPTIONS ...]] <endpoint> [main-args]",
         epilog=epilog,
         formatter_class=argparse.RawTextHelpFormatter,
     )
@@ -364,13 +341,13 @@ and it will be auto-completed.
         "-m",
         "--manage-dependencies",
         action="store_true",
-        help='use endpoints for dependency management (see "Details" below)',
+        help='use endpoints for dependency management (see "Pitfalls")',
     )
     parser.add_argument(
         "-r",
         "--repository",
         nargs="+",
-        help="Add additional maven repository (key=url format)",
+        help="Add additional Maven repository (key=url format)",
         default=[],
         required=False,
     )
@@ -401,7 +378,8 @@ and it will be auto-completed.
         "--link-type",
         default=None,
         type=str,
-        help="How to link from local maven repository into jgo cache. Defaults to the `links' setting in ~/.jgorc or 'auto' if not specified.",
+        help="How to link from local Maven repository into jgo cache.\n" +
+             "Defaults to the `links' setting in ~/.jgorc or 'auto' if not specified.",
         choices=("hard", "soft", "copy", "auto"),
     )
     parser.add_argument(
@@ -657,19 +635,33 @@ def resolve_dependencies(
         mvn = executable_path_or_raise("mvn")
         mvn_out = run_and_combine_outputs(mvn, *mvn_args)
     except subprocess.CalledProcessError as e:
-        _logger.info("Failed to bootstrap the artifact.")
-        _logger.info("")
-        _logger.info("Possible solutions:")
-        _logger.info(
+        _logger.error("Failed to bootstrap the artifact.")
+        _logger.error("")
+
+        _logger.error("Possible solutions:")
+        _logger.error(
             "* Double check the endpoint for correctness (https://search.maven.org/)."
         )
-        _logger.info(
+        _logger.error(
             "* Add needed repositories to ~/.jgorc [repositories] block (see README)."
         )
-        _logger.info(
+        _logger.error(
             "* Try with an explicit version number (release metadata might be wrong)."
         )
-        print()
+        _logger.error("")
+        _logger.error("Full Maven error output:")
+        err_lines = []
+        if e.stdout:
+            err_lines += e.stdout.decode().splitlines()
+        if e.stderr:
+            err_lines += e.stderr.decode().splitlines()
+        for l in err_lines:
+            if l.startswith('[ERROR]'):
+                _logger.error("\t%s", l)
+            else:
+                _logger.debug("\t%s", l)
+        _logger.error("")
+
         raise e
 
     info_regex = re.compile("^.*\\[[A-Z]+\\] *")
@@ -683,7 +675,7 @@ def resolve_dependencies(
             and not re.match(".*:provided", l)
         ):
 
-            _logger.debug("Relevant maven output: %s", l)
+            _logger.debug("Relevant mvn output: %s", l)
 
             split_line = info_regex.sub("", l).split(":")
             split_line_len = len(split_line)
